==> ecuacion-lib-core-14.7.0-sources.jar: jp/ecuacion/lib/core/jakartavalidation/validator/ConditionalNotEmptyValidator.java <==
/*
 * Copyright © 2012 ecuacion.jp (info@ecuacion.jp)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.ecuacion.lib.core.jakartavalidation.validator;

import jakarta.validation.ConstraintValidator;
import jp.ecuacion.lib.core.constant.EclibCoreConstants;
import jp.ecuacion.lib.core.jakartavalidation.validator.internal.ConditionalValidator;
import org.apache.commons.lang3.StringUtils;

/**
 * Provides the validation logic for {@code EnumElement}.
 */
public class ConditionalNotEmptyValidator extends ConditionalValidator
    implements ConstraintValidator<ConditionalNotEmpty, Object> {

  /** Initializes an instance. */
  @Override
  public void initialize(ConditionalNotEmpty annotation) {
    super.initialize(annotation.field(), annotation.conditionField(), annotation.conditionValue(),
        annotation.conditionValueIsEmpty(), annotation.conditionValueIsNotEmpty(),
        annotation.fieldHoldingConditionValue());
  }

  @Override
  protected boolean isValid(Object valueOfField) {
    if (valueOfField != null && valueOfField.equals(EclibCoreConstants.VALIDATOR_PARAMETER_NULL)) {
      valueOfField = null;
    }

    if (valueOfField != null && valueOfField instanceof String) {
      return !StringUtils.isEmpty((String) valueOfField);

    } else {
      return valueOfField != null;
    }
  }
}

==> ecuacion-lib-core-14.10.2-sources.jar: jp/ecuacion/lib/core/jakartavalidation/validator/ConditionalNotEmptyValidator.java <==
/*
 * Copyright © 2012 ecuacion.jp (info@ecuacion.jp)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package jp.ecuacion.lib.core.jakartavalidation.validator;

import jakarta.validation.ConstraintValidator;
import jp.ecuacion.lib.core.constant.EclibCoreConstants;
import jp.ecuacion.lib.core.jakartavalidation.validator.internal.ConditionalValidator;
import org.apache.commons.lang3.StringUtils;

/**
 * Provides the validation logic for {@code EnumElement}.
 */
public class ConditionalNotEmptyValidator extends ConditionalValidator
    implements ConstraintValidator<ConditionalNotEmpty, Object> {

  /** Initializes an instance. */
  @Override
  public void initialize(ConditionalNotEmpty annotation) {
    super.initialize(annotation.field(), annotation.conditionField(), annotation.conditionValue(),
        annotation.conditionValueIsEmpty(), annotation.conditionValueIsNotEmpty(),
        annotation.fieldHoldingConditionValue(), annotation.emptyForOtherValues());
  }

  @Override
  protected boolean isValid(Object valueOfField) {
    if (valueOfField != null && valueOfField.equals(EclibCoreConstants.VALIDATOR_PARAMETER_NULL)) {
      valueOfField = null;
    }

    if (valueOfField != null && valueOfField instanceof String) {
      return !StringUtils.isEmpty((String) valueOfField);

    } else {
      return valueOfField != null;
    }
  }

  @Override
  protected boolean isValidWhenConditionNotSatisfied(Object valueOfField) {
    return !isValid(valueOfField);
  }
}
